==> jc-1.4.0.tar.gz: javax/net/VanillaSocketFactory.h <==
// class javax.net.VanillaSocketFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ae720b2f6afde56 javax_net_SocketFactory
// @dep_class b6c5aab2650fd904 javax_net_VanillaSocketFactory

// header file dependencies
// @dep_header javax_net_SocketFactory

#include "javax/net/SocketFactory.h"

#ifndef _JC_javax_net_VanillaSocketFactory_H_
#define _JC_javax_net_VanillaSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_InetAddress$object;
struct _jc_java_net_Socket$object;

// Typedefs
typedef struct _jc_javax_net_VanillaSocketFactory$sub_refs	_jc_javax_net_VanillaSocketFactory$sub_refs;
typedef struct _jc_javax_net_VanillaSocketFactory$sub_nonrefs	_jc_javax_net_VanillaSocketFactory$sub_nonrefs;
typedef struct _jc_javax_net_VanillaSocketFactory$refs	_jc_javax_net_VanillaSocketFactory$refs;
typedef struct _jc_javax_net_VanillaSocketFactory$nonrefs	_jc_javax_net_VanillaSocketFactory$nonrefs;
typedef struct _jc_javax_net_VanillaSocketFactory$object	_jc_javax_net_VanillaSocketFactory$object;

typedef const struct _jc_javax_net_VanillaSocketFactory$vmethods	_jc_javax_net_VanillaSocketFactory$vmethods;
typedef const struct _jc_javax_net_VanillaSocketFactory$vtable	_jc_javax_net_VanillaSocketFactory$vtable;
typedef const struct _jc_javax_net_VanillaSocketFactory$vtype	_jc_javax_net_VanillaSocketFactory$vtype;

// Constructors
extern void _jc_javax_net_VanillaSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *);

// Virtual methods
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$128d0ac2e1ddd4ba(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *);
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$0d93b2802005a3fd(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_lang_String$object *, jint);
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$83be123e6180bcfb(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_net_InetAddress$object *, jint);
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$c0bcd792cf7e0d35(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_net_InetAddress$object *, jint);
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$d3aaa3ed13cae3dc(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_net_InetAddress$object *, jint, struct _jc_java_net_InetAddress$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$128d0ac2e1ddd4ba;
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$0d93b2802005a3fd;
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$83be123e6180bcfb;
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$c0bcd792cf7e0d35;
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$d3aaa3ed13cae3dc;

// Virtual methods structure
struct _jc_javax_net_VanillaSocketFactory$vmethods {
	struct _jc_java_net_Socket$object	*(*createSocket$128d0ac2e1ddd4ba)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *);
	struct _jc_java_net_Socket$object	*(*createSocket$0d93b2802005a3fd)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_lang_String$object *, jint);
	struct _jc_java_net_Socket$object	*(*createSocket$83be123e6180bcfb)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_net_InetAddress$object *, jint);
	struct _jc_java_net_Socket$object	*(*createSocket$c0bcd792cf7e0d35)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_net_InetAddress$object *, jint);
	struct _jc_java_net_Socket$object	*(*createSocket$d3aaa3ed13cae3dc)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_net_InetAddress$object *, jint, struct _jc_java_net_InetAddress$object *, jint);
};

// Vtable
struct _jc_javax_net_VanillaSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_SocketFactory$vmethods	javax_net_SocketFactory;
	_jc_javax_net_VanillaSocketFactory$vmethods	javax_net_VanillaSocketFactory;
};

// Vtype
struct _jc_javax_net_VanillaSocketFactory$vtype {
	_jc_type			type;
	_jc_javax_net_VanillaSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_VanillaSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_VanillaSocketFactory$refs {
    _jc_javax_net_VanillaSocketFactory$sub_refs	javax_net_VanillaSocketFactory;
    _jc_javax_net_SocketFactory$sub_refs	javax_net_SocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_VanillaSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_VanillaSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_SocketFactory$sub_nonrefs	javax_net_SocketFactory;
    _jc_javax_net_VanillaSocketFactory$sub_nonrefs	javax_net_VanillaSocketFactory;
};

// Object instance structure
struct _jc_javax_net_VanillaSocketFactory$object {
	_jc_javax_net_VanillaSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_VanillaSocketFactory$vtype	*vtype;
	_jc_javax_net_VanillaSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_VanillaSocketFactory$vtype _jc_javax_net_VanillaSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_VanillaSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_VanillaSocketFactory$class_object;

#endif	/* _JC_javax_net_VanillaSocketFactory_H_ */

==> jc-1.4.6.tar.gz: javax/net/VanillaSocketFactory.h <==
// class javax.net.VanillaSocketFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ae720b2f6afde56 javax_net_SocketFactory
// @dep_class b6c5aab2650fd904 javax_net_VanillaSocketFactory

// header file dependencies
// @dep_header javax_net_SocketFactory

#include "javax/net/SocketFactory.h"

#ifndef _JC_javax_net_VanillaSocketFactory_H_
#define _JC_javax_net_VanillaSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_InetAddress$object;
struct _jc_java_net_Socket$object;

// Typedefs
typedef struct _jc_javax_net_VanillaSocketFactory$sub_refs	_jc_javax_net_VanillaSocketFactory$sub_refs;
typedef struct _jc_javax_net_VanillaSocketFactory$sub_nonrefs	_jc_javax_net_VanillaSocketFactory$sub_nonrefs;
typedef struct _jc_javax_net_VanillaSocketFactory$refs	_jc_javax_net_VanillaSocketFactory$refs;
typedef struct _jc_javax_net_VanillaSocketFactory$nonrefs	_jc_javax_net_VanillaSocketFactory$nonrefs;
typedef struct _jc_javax_net_VanillaSocketFactory$object	_jc_javax_net_VanillaSocketFactory$object;

typedef const struct _jc_javax_net_VanillaSocketFactory$vmethods	_jc_javax_net_VanillaSocketFactory$vmethods;
typedef const struct _jc_javax_net_VanillaSocketFactory$vtable	_jc_javax_net_VanillaSocketFactory$vtable;
typedef const struct _jc_javax_net_VanillaSocketFactory$vtype	_jc_javax_net_VanillaSocketFactory$vtype;

// Constructors
extern void _jc_javax_net_VanillaSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$128d0ac2e1ddd4ba(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$0d93b2802005a3fd(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$83be123e6180bcfb(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_net_InetAddress$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$c0bcd792cf7e0d35(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_net_InetAddress$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_net_Socket$object *_jc_javax_net_VanillaSocketFactory$method$createSocket$d3aaa3ed13cae3dc(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_net_InetAddress$object *, jint, struct _jc_java_net_InetAddress$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$128d0ac2e1ddd4ba;
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$0d93b2802005a3fd;
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$83be123e6180bcfb;
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$c0bcd792cf7e0d35;
extern _jc_method _jc_javax_net_VanillaSocketFactory$method_info$createSocket$d3aaa3ed13cae3dc;

// Virtual methods structure
struct _jc_javax_net_VanillaSocketFactory$vmethods {
	struct _jc_java_net_Socket$object	*(*createSocket$128d0ac2e1ddd4ba)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_Socket$object	*(*createSocket$0d93b2802005a3fd)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_net_Socket$object	*(*createSocket$83be123e6180bcfb)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_net_InetAddress$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_net_Socket$object	*(*createSocket$c0bcd792cf7e0d35)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_net_InetAddress$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_net_Socket$object	*(*createSocket$d3aaa3ed13cae3dc)(_jc_env *, struct _jc_javax_net_VanillaSocketFactory$object *, struct _jc_java_net_InetAddress$object *, jint, struct _jc_java_net_InetAddress$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_VanillaSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_SocketFactory$vmethods	javax_net_SocketFactory;
	_jc_javax_net_VanillaSocketFactory$vmethods	javax_net_VanillaSocketFactory;
};

// Vtype
struct _jc_javax_net_VanillaSocketFactory$vtype {
	_jc_type			type;
	_jc_javax_net_VanillaSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_VanillaSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_VanillaSocketFactory$refs {
    _jc_javax_net_VanillaSocketFactory$sub_refs	javax_net_VanillaSocketFactory;
    _jc_javax_net_SocketFactory$sub_refs	javax_net_SocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_VanillaSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_VanillaSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_SocketFactory$sub_nonrefs	javax_net_SocketFactory;
    _jc_javax_net_VanillaSocketFactory$sub_nonrefs	javax_net_VanillaSocketFactory;
};

// Object instance structure
struct _jc_javax_net_VanillaSocketFactory$object {
	_jc_javax_net_VanillaSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_VanillaSocketFactory$vtype	*vtype;
	_jc_javax_net_VanillaSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_VanillaSocketFactory$vtype _jc_javax_net_VanillaSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_VanillaSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_VanillaSocketFactory$class_object;

#endif	/* _JC_javax_net_VanillaSocketFactory_H_ */
